@@ -24,13 +24,12 @@ from ft.onto.base_ontology import Utterance
 
 logger = logging.getLogger(__name__)
 
-__all__ = [
-    "MultiPackTerminalReader"
-]
+__all__ = ["MultiPackTerminalReader"]
 
 
 class MultiPackTerminalReader(MultiPackReader):
-    r"""A reader designed to read text from the terminal."""
+    r"""A reader designed to read text from the terminal. and returns a
+    multi-pack that contains this single pack."""
 
     # pylint: disable=unused-argument
     def _cache_key_function(self, collection) -> str:
@@ -41,7 +40,7 @@ class MultiPackTerminalReader(MultiPackReader):
         # strings.
         while True:
             try:
-                data = input("Enter your query here: ")
+                data = input(self.configs.prompt_text)
                 if len(data) == 0:
                     continue
                 yield data
@@ -62,14 +61,16 @@ class MultiPackTerminalReader(MultiPackReader):
         # use context to build the query
         if self.resources is not None and self.resources.get("user_utterance"):
             multi_pack.add_pack_(
-                self.resources.get("user_utterance")[-1], "user_utterance")
+                self.resources.get("user_utterance")[-1], "user_utterance"
+            )
 
         if self.resources is not None and self.resources.get("bot_utterance"):
             multi_pack.add_pack_(
-                self.resources.get("bot_utterance")[-1], "bot_utterance")
+                self.resources.get("bot_utterance")[-1], "bot_utterance"
+            )
 
         pack = multi_pack.add_pack(self.configs.pack_name)
-        pack.set_text(data_source, replace_func=self.text_replace_operation)
+        self.set_text(pack, data_source)
 
         Utterance(pack, 0, len(data_source))
 
@@ -77,6 +78,29 @@ class MultiPackTerminalReader(MultiPackReader):
 
     @classmethod
     def default_configs(cls) -> Dict[str, Any]:
+        """
+        Defines the default configuration for this class, available options are:
+
+        .. code-block:: python
+
+            {
+                "pack_name": "query",
+                "prompt_text": "Enter your query here: ",
+            }
+
+        The `pack_name` is the named to be assigned to the pack to identify it
+        in the multi-pack. The `prompt_text` is the text shown on the terminal.
+
+        Returns: The default configuration values as a dict.
+
+        """
         configs = super().default_configs()
+        configs.update(
+            {
+                "pack_name": "query",
+                "prompt_text": "Enter your query here: ",
+            }
+        )
+
         configs["pack_name"] = "query"
         return configs
