@@ -15,7 +15,7 @@
 The reader that reads plain text data into Datapacks.
 """
 import logging
-from typing import Iterator, List, Union
+from typing import Iterator, List, Union, Dict, Set
 
 from forte.data.data_pack import DataPack
 from forte.data.base_reader import PackReader
@@ -29,22 +29,25 @@ __all__ = [
 
 
 class StringReader(PackReader):
-    r""":class:`StringReader` is designed to read in a list of string variables.
+    r"""
+    :class:`StringReader` is designed to read in a list of string variables.
     """
 
     # pylint: disable=unused-argument
     def _cache_key_function(self, collection) -> str:
-        return str(hash(collection)) + '.html'
+        return str(hash(collection)) + ".html"
 
-    def _collect(self,  # type: ignore
-                 string_data: Union[List[str], str]) -> Iterator[str]:
+    def _collect(  # type: ignore
+        self, string_data: Union[List[str], str]
+    ) -> Iterator[str]:
         r"""``string`_data` should be of type `List[str]`,
         which is the list of raw text strings to iterate over.
         """
         # This allows the user to pass in either one single string or a list of
         # strings.
-        data_strings = [string_data] if isinstance(
-            string_data, str) else string_data
+        data_strings = (
+            [string_data] if isinstance(string_data, str) else string_data
+        )
         for data in data_strings:
             yield data
 
@@ -62,3 +65,14 @@ class StringReader(PackReader):
         Document(pack, 0, len(data_source))
 
         yield pack
+
+    def record(self, record_meta: Dict[str, Set[str]]):
+        r"""Method to add output type record of `StringReader` which is
+        `ft.onto.base_ontology.Document` with an empty set
+        to :attr:`forte.data.data_pack.Meta.record`.
+
+        Args:
+            record_meta: the field in the datapack for type record that need to
+                fill in for consistency checking.
+        """
+        record_meta["ft.onto.base_ontology.Document"] = set()
