@@ -77,11 +77,13 @@ class CustomLSTMCell(tx.core.RNNCellBase[LSTMState]):
         self._dropout_mask = None
 
     def zero_state(self, batch_size: int) -> LSTMState:
-        return (self._initial_hidden.expand(batch_size, -1),
-                self._initial_cell.expand(batch_size, -1))
+        return (
+            self._initial_hidden.expand(batch_size, -1),
+            self._initial_cell.expand(batch_size, -1),
+        )
 
     def forward(
-            self, input_tensor: torch.Tensor, state: Optional[LSTMState] = None
+        self, input_tensor: torch.Tensor, state: Optional[LSTMState] = None
     ) -> Tuple[torch.Tensor, LSTMState]:
         batch_size = input_tensor.size(0)
         if state is None:
@@ -91,7 +93,8 @@ class CustomLSTMCell(tx.core.RNNCellBase[LSTMState]):
             if self._dropout_mask is None:
                 keep_prob = 1 - self._dropout_rate
                 self._dropout_mask = input_tensor.new_zeros(
-                    batch_size, self._hidden_size).bernoulli_(keep_prob)
+                    batch_size, self._hidden_size
+                ).bernoulli_(keep_prob)
             h = h * self._dropout_mask
         concat_proj = self._projection(torch.cat([input_tensor, h], dim=1))
         i, g, o = torch.chunk(concat_proj, 3, dim=1)
@@ -116,9 +119,12 @@ class CustomBiLSTM(tx.modules.EncoderBase):
             self.bw_cells.append(bw_cell)
             input_dim = 2 * hidden_dim
 
-        self.highway_layers = nn.ModuleList([
-            nn.Linear(hidden_dim * 2, hidden_dim * 2)
-            for _ in range(self._hparams.num_layers - 1)])
+        self.highway_layers = nn.ModuleList(
+            [
+                nn.Linear(hidden_dim * 2, hidden_dim * 2)
+                for _ in range(self._hparams.num_layers - 1)
+            ]
+        )
 
         self.dropout = nn.Dropout(self._hparams.dropout)
 
@@ -131,14 +137,18 @@ class CustomBiLSTM(tx.modules.EncoderBase):
             "dropout": 0.2,
         }
 
-    def forward(self, inputs: torch.Tensor,
-                sequence_length: Optional[torch.LongTensor] = None) \
-            -> torch.Tensor:
+    def forward(
+        self,
+        inputs: torch.Tensor,
+        sequence_length: Optional[torch.LongTensor] = None,
+    ) -> torch.Tensor:
         for idx in range(self._hparams.num_layers):
-            (fw_outputs, bw_outputs), _ = \
-                tx.utils.rnn.bidirectional_dynamic_rnn(
-                    self.fw_cells[idx], self.bw_cells[idx],
-                    inputs, sequence_length)
+            (
+                fw_outputs,
+                bw_outputs,
+            ), _ = tx.utils.rnn.bidirectional_dynamic_rnn(
+                self.fw_cells[idx], self.bw_cells[idx], inputs, sequence_length
+            )
             outputs = torch.cat([fw_outputs, bw_outputs], dim=2)
             outputs = self.dropout(outputs)
             if idx > 0:
@@ -156,15 +166,21 @@ class CharCNN(tx.ModuleBase):
 
         self.char_vocab = char_vocab
         self.char_embed = tx.modules.WordEmbedder(
-            vocab_size=self.char_vocab.size, hparams={
+            vocab_size=self.char_vocab.size,
+            hparams={
                 "dim": self._hparams.char_embed_size,
-            })
-        self.cnn_kernels = nn.ModuleList([
-            nn.Conv1d(
-                self._hparams.char_embed_size,
-                self._hparams.filter_size,
-                kernel_size=width
-            ) for width in self._hparams.filter_widths])
+            },
+        )
+        self.cnn_kernels = nn.ModuleList(
+            [
+                nn.Conv1d(
+                    self._hparams.char_embed_size,
+                    self._hparams.filter_size,
+                    kernel_size=width,
+                )
+                for width in self._hparams.filter_widths
+            ]
+        )
         self._max_filter_width = max(self._hparams.filter_widths)
 
     @staticmethod
@@ -181,7 +197,7 @@ class CharCNN(tx.ModuleBase):
 
     @property
     def _device(self) -> torch.device:
-        if not hasattr(self, '__torch_device__'):
+        if not hasattr(self, "__torch_device__"):
             self.__torch_device__ = next(self.parameters()).device
         return self.__torch_device__
 
@@ -210,24 +226,27 @@ class CharCNN(tx.ModuleBase):
         char_indices = np.zeros((len(all_words), max_word_len), dtype=np.int64)
         for idx, word in enumerate(all_words):
             char_ids = self.char_vocab.map_tokens_to_ids_py(list(word))
-            char_indices[idx, :len(word)] = char_ids
+            char_indices[idx, : len(word)] = char_ids
         indices = torch.from_numpy(char_indices).to(self._device)
 
         # embed: (batch_size * max_length, char_embed_dim, max_word_len)
         embed = self.char_embed(indices).transpose(1, 2)
         if max_word_len < self._max_filter_width:
             pad_length = self._max_filter_width - max_word_len
-            embed = torch.cat([embed, embed.new_zeros(
-                *embed.size()[:2], pad_length)], dim=2)
+            embed = torch.cat(
+                [embed, embed.new_zeros(*embed.size()[:2], pad_length)], dim=2
+            )
         kernel_outputs = [kernel(embed) for kernel in self.cnn_kernels]
         cnn_output = torch.cat(
-            [torch.max(out, dim=2)[0] for out in kernel_outputs], dim=1)
+            [torch.max(out, dim=2)[0] for out in kernel_outputs], dim=1
+        )
 
         sent_cnn_outputs = torch.split(cnn_output, sent_lengths, dim=0)
         output = cnn_output.new_zeros(
-            len(words), max_length, cnn_output.size(1))
+            len(words), max_length, cnn_output.size(1)
+        )
         for idx, sent_output in enumerate(sent_cnn_outputs):
-            output[idx, :sent_lengths[idx]] = sent_output
+            output[idx, : sent_lengths[idx]] = sent_output
         return output
 
 
@@ -240,13 +259,17 @@ def sum_list(xs: List[torch.Tensor]) -> torch.Tensor:
 
 # pylint: disable=unused-argument,function-redefined
 @overload
-def batch_gather(tensors: List[torch.Tensor],
-                 index: torch.LongTensor) -> List[torch.Tensor]: ...
+def batch_gather(
+    tensors: List[torch.Tensor], index: torch.LongTensor
+) -> List[torch.Tensor]:
+    ...
 
 
 @overload
-def batch_gather(tensors: torch.Tensor,
-                 index: torch.LongTensor) -> torch.Tensor: ...
+def batch_gather(
+    tensors: torch.Tensor, index: torch.LongTensor
+) -> torch.Tensor:
+    ...
 
 
 def batch_gather(tensors, index):
@@ -292,7 +315,8 @@ class MLP(tx.ModuleBase):
         else:
             activation = None
         for has_bias, output_size in zip(
-                self._hparams.has_bias, self._hparams.hidden_size):
+            self._hparams.has_bias, self._hparams.hidden_size
+        ):
             layers.append(nn.Linear(input_size, output_size, bias=has_bias))
             input_size = output_size
             if activation is not None:
@@ -348,10 +372,12 @@ class ConcatInputMLP(tx.ModuleBase):
         yield
         del self._cached_inputs
 
-    def forward(self, inputs: List[Union[torch.Tensor,
-                                         List[Tuple[torch.Tensor,
-                                                    torch.Tensor]]]]) \
-            -> torch.Tensor:
+    def forward(
+        self,
+        inputs: List[
+            Union[torch.Tensor, List[Tuple[torch.Tensor, torch.Tensor]]]
+        ],
+    ) -> torch.Tensor:
         """
 
         Args:
