@@ -11,6 +11,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from typing import Optional
+
 from forte.common.exception import ProcessExecutionException
 from forte.data.data_pack import DataPack
 from forte.data.multi_pack import MultiPack
@@ -18,18 +20,19 @@ from forte.processors.base.writers import JsonPackWriter, MultiPackWriter
 
 
 class PackIdJsonPackWriter(JsonPackWriter):
-    def sub_output_path(self, pack: DataPack) -> str:
-        suffix = '.json.gz' if self.zip_pack else '.json'
+    def sub_output_path(self, pack: DataPack) -> Optional[str]:
+        suffix = ".json.gz" if self.zip_pack else ".json"
         return str(pack.pack_id) + suffix
 
 
 class PackNameJsonPackWriter(JsonPackWriter):
-    def sub_output_path(self, pack: DataPack) -> str:
+    def sub_output_path(self, pack: DataPack) -> Optional[str]:
         if pack.pack_name is None:
             raise ValueError(
                 "Cannot use DocIdJsonPackWriter when [pack_name] of the pack "
-                "is not set.")
-        suffix = '.json.gz' if self.zip_pack else '.json'
+                "is not set."
+            )
+        suffix = ".json.gz" if self.zip_pack else ".json"
         return pack.pack_name + suffix
 
 
@@ -38,16 +41,18 @@ class PackNameMultiPackWriter(MultiPackWriter):
         name = pack.pack_name
         if name is None:
             raise ProcessExecutionException(
-                'Cannot used the DocIdMultiPackWriter because the [pack_name] '
-                'is not assigned for the pack.')
+                "Cannot used the DocIdMultiPackWriter because the [pack_name] "
+                "is not assigned for the pack."
+            )
         return name
 
     def multipack_name(self, pack: MultiPack) -> str:
         name = pack.pack_name
         if name is None:
             raise ProcessExecutionException(
-                'Cannot used the DocIdMultiPackWriter because the doc id is '
-                'not assigned for the pack.')
+                "Cannot used the DocIdMultiPackWriter because the doc id is "
+                "not assigned for the pack."
+            )
         return name
 
 
