@@ -17,11 +17,7 @@ Utility functions related to input/output.
 import os
 
 
-__all__ = [
-    "maybe_create_dir",
-    "ensure_dir",
-    "get_resource"
-]
+__all__ = ["maybe_create_dir", "ensure_dir", "get_resource"]
 
 import sys
 
